@@ -19,7 +19,7 @@ from twitter import Api
 import readrss
 from shortener import services
 from httplib import BadStatusLine
-from urllib2 import HTTPError
+from urllib2 import HTTPError, URLError
 import time
 import re
 import logging
@@ -33,14 +33,14 @@ class Microblog(object):
         return txt.replace('(Comments)','')
 
     def update(self):
-        log.info ('searching new items to publish on ' +self.alias)
+        log.info ('searching new items to publish on ' + self.alias)
         lastread = self.rss.getlastRead()
         if not lastread:
             log.info ("There's no record of previous update on " + self.alias)
             log.info ('new items to update:' + str(self.items))
             self.postIt(reversed(self.rss.feed['items'][:self.items]))
         else:
-            log.info ('last ' + self.__class__.__name__.lower() + ' update time: ' + str(lastread))
+            log.info ('last ' + self.alias + ' update time: ' + time.strftime("%Y-%m-%d %H:%M:%S",lastread))
             try:
                 lista = [item for item in self.rss.feed['items'] if item['published_parsed'] > lastread]
             except:
@@ -63,10 +63,10 @@ class Microblog(object):
             try:
                 status = self.api.PostUpdate(txt)
                 self.rss.updateLastRead(it)
-                log.info(status.text + " posted on " + self.__class__.__name__.lower())
+                log.info(status.text + " posted on " + self.alias)
                 time.sleep(5)
 
-            except (BadStatusLine, HTTPError):
+            except (BadStatusLine, HTTPError, URLError):
                 #lets try in the next time
                 return
 
@@ -172,7 +172,7 @@ class Wordpress(Microblog):
             try:
                 status = self.api.PostUpdate(post)
                 self.rss.updateLastRead(it)
-                log.info(status.text + " posted on " + self.__class__.__name__.lower())
+                log.info(status.text + " posted on " + self.alias)
                 time.sleep(5)
 
             except (BadStatusLine, HTTPError):
